@@ -1,9 +1,9 @@
 import logging
-from tornado.testing import ExpectLog
+import unittest
 
 from plop.callgraph import CallGraph, Node
 
-class SimpleCallgraphTest(ExpectLog):
+class SimpleCallgraphTest(unittest.TestCase):
     def setUp(self):
         graph = CallGraph()
         graph.add_stack([Node(1), Node(2)], dict(time=1))
@@ -13,14 +13,14 @@ class SimpleCallgraphTest(ExpectLog):
         self.graph = graph
 
     def test_basic_attrs(self):
-        logging.info(self.graph.nodes)
-        logging.info(self.graph.edges)
+        logging.debug(self.graph.nodes)
+        logging.debug(self.graph.edges)
         self.assertEqual(len(self.graph.nodes), 4)
         self.assertEqual(len(self.graph.edges), 5)
-                
+
     def test_top_edges(self):
         top_edges = self.graph.get_top_edges('time', 3)
-        logging.info(top_edges)
+        logging.debug(top_edges)
         summary = [(e.parent.id, e.child.id, e.weights['time']) for e in top_edges]
         self.assertEqual(summary, [
                 (2, 3, 9),
@@ -30,7 +30,7 @@ class SimpleCallgraphTest(ExpectLog):
 
     def test_top_nodes(self):
         top_nodes = self.graph.get_top_nodes('time', 2)
-        logging.info(top_nodes)
+        logging.debug(top_nodes)
         summary = [(n.id, n.weights['time']) for n in top_nodes]
         self.assertEqual(summary, [
                 (3, 12),
